"use client";

import { z } from "zod";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import { toast } from "@/hooks/use-toast";
import { useForm } from "react-hook-form";
import { Textarea } from "@/components/ui/textarea";
import { zodResolver } from "@hookform/resolvers/zod";

const detailsFormSchema = z.object({
  description: z.string().min(1, { message: "题目描述不能为空" }),
});

type DetailsFormValues = z.infer<typeof detailsFormSchema>;

export function DeatilsForm() {
  const form = useForm<DetailsFormValues>({
    resolver: zodResolver(detailsFormSchema),
    defaultValues: {
      description: "",
    },
  });

  function onSubmit(data: DetailsFormValues) {
    toast({
      title: "题目详细内容创建成功",
      description: (
        <div>
          <p>题目描述：{data.description}</p>
        </div>
      ),
    });
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="description"
          render={({ field }) => (
            <FormItem>
              <FormLabel>题目描述</FormLabel>
              <FormControl>
                <Textarea placeholder="描述题目要求即可" className="h-72"{...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
      </form>
    </Form>
  );
}
